##################################################
# NOTE:                                          
# Change this directory to the location of the   
# unzipped replication archive                   
##################################################

setwd('C:/Documents and Settings/Administrator/Desktop/CWS_IO_2011_rep')


###############
# Load data   #
###############

data1 <- read.csv("CWS.MajorPowerWars.csv")
data2 <- read.csv("CWS.InterstateWars.csv")


##########################################################
# First, we confirm the power-law distributional form 
# for major power wars (1495-1997), using the TP-statistic          
# (Figure A1)                                         
##########################################################

x <- sort(na.omit(data1$deaths_mpw))

lowerbound <- 3
upperbound <- 7.4
increment <- 0.02
numrows <- floor((upperbound - lowerbound) / increment) + 1

results.TP <- matrix(NA,numrows,6)
colnames(results.TP) <- c("Threshold","Exponent","TP","TPsd","low95","high95")
rowindex <- 1

for (t in seq(lowerbound, upperbound, by = increment)) {
	u <- 10^t
	s <- x[x >= u]
	n <- length(s)
	alpha <- ((sum(log(s/u)))/n)^-1
	TP <- (((1/n)*sum(log(s/u)))^2) - ((0.5/n)*sum((log(s/u))^2))
	TPsd <- (n^(-0.5))*(((1/n)*sum(((2*(1/n)*sum(log(s/u))*log(s/u)) - (0.5*((log(s/u))^2)) - 1/((alpha)^2))^2))^0.5)
	results.TP[rowindex,1] <- u
	results.TP[rowindex,2] <- alpha
	results.TP[rowindex,3] <- TP
	results.TP[rowindex,4] <- TPsd
	results.TP[rowindex,5] <- 0 - (2 * TPsd)
	results.TP[rowindex,6] <- 0 + (2 * TPsd)
	rowindex <- rowindex + 1
}

results.TP <- as.data.frame(results.TP)
results.TP

#write.table(results.TP, file = "Figure1A.results.csv", sep = ",", row.names = FALSE)


#####################################################
# Next, we calculate the powerlaw exponent 'alpha'  
# using the Hill estimator, and the minimum threshold   
# of 10,000 battle-deaths shown by the TP-statistic,
# for both the pre-1789 and post-1789 periods  
#####################################################

deaths.pre1789  <- na.omit(data1$deaths_mpw[data1$year_mpw < 1789])
deaths.post1789 <- na.omit(data1$deaths_mpw[data1$year_mpw > 1789])

deaths.pre1789.10k  <- na.omit(deaths.pre1789[deaths.pre1789 >= 10000])
deaths.post1789.10k <- na.omit(deaths.post1789[deaths.post1789 >= 10000])

hill.pre1789  <- ((sum(log(deaths.pre1789.10k / 10000)))  / length(deaths.pre1789.10k))  ^ -1
hill.post1789 <- ((sum(log(deaths.post1789.10k / 10000))) / length(deaths.post1789.10k)) ^ -1


############
# alpha 1  #
############

hill.pre1789

############
# alpha 2  #
############

hill.post1789


#####################################################
# Next, we test the statisticalsignificance of the   
# distributional shift between the two time periods
# using an F-test  
#####################################################

ratio <- hill.pre1789 / hill.post1789
1 - pf(ratio, 48, 106)


#####################################################
# Next, we demonstrate the uniqueness of the 1789 shift  
# by comparing Kolmogorov-Smirnov distances accross
# subsamples defined by all possible alternative cut-points
# and a fixed-width sliding window 
#
# NOTE: The critical value for this test is 1.36
# at the 95% confidence level
#####################################################

cutyear <- 1549
window <- 75

results.KS <- matrix(NA,440,2)
colnames(results.KS) <- c("Year","KS_distance")

for (d in c(1:440)) {
	cutyear <- cutyear + 1
	pre <- na.omit(sort(data1$deaths_mpw[data1$year_mpw < cutyear & data1$year_mpw > (cutyear - window)]))
	post <- na.omit(sort(data1$deaths_mpw[data1$year_mpw > cutyear & data1$year_mpw < (cutyear + window)]))
	out <- ks.test(pre, post)
	n <- length(pre)
	m <- length(post)
	distance <- out$statistic * (((n * m)/(n + m)) ^ 0.5)
	results.KS[d,1] <- cutyear 
	results.KS[d,2] <- distance
}

results.KS <- as.data.frame(results.KS)
results.KS

#write.table(results.KS, file = "Figure2.results.csv", sep = ",", row.names = FALSE)


###########################################################
# Next, we confirm the robustness of the cut-point  
# analysis by performing the same procedure on the 
# battle death data normalized by yearly global GDP     
###########################################################

cutyear <- 1549
window <- 75

results.KS.GDPpc <- matrix(NA,440,2)
colnames(results.KS.GDPpc) <- c("Year","KS_distance")

for (d in c(1:440)) {
	cutyear <- cutyear + 1
	pre <- na.omit(sort(data1$deaths_mpw_gdppc[data1$year_mpw < cutyear & data1$year_mpw > (cutyear - window)]))
	post <- na.omit(sort(data1$deaths_mpw_gdppc[data1$year_mpw > cutyear & data1$year_mpw < (cutyear + window)]))
	out <- ks.test(pre, post)
	n <- length(pre)
	m <- length(post)
	distance <- out$statistic * (((n * m)/(n + m)) ^ 0.5)
	results.KS.GDPpc[d,1] <- cutyear 
	results.KS.GDPpc[d,2] <- distance
}

results.KS.GDPpc <- as.data.frame(results.KS.GDPpc)
results.KS.GDPpc

###########################################################
# Next, we confirm the robustness of the cut-point  
# analysis by performing the same procedure on the 
# battle death data normalized by yearly global population     
###########################################################

cutyear <- 1549
window <- 75

results.KS.pop <- matrix(NA,440,2)
colnames(results.KS.pop) <- c("Year","KS_distance")

for (d in c(1:440)) {
	cutyear <- cutyear + 1
	pre <- na.omit(sort(data1$deaths_mpw_pop[data1$year_mpw < cutyear & data1$year_mpw > (cutyear - window)]))
	post <- na.omit(sort(data1$deaths_mpw_pop[data1$year_mpw > cutyear & data1$year_mpw < (cutyear + window)]))
	out <- ks.test(pre, post)
	n <- length(pre)
	m <- length(post)
	distance <- out$statistic * (((n * m)/(n + m)) ^ 0.5)
	results.KS.pop[d,1] <- cutyear 
	results.KS.pop[d,2] <- distance
}

results.KS.pop <- as.data.frame(results.KS.pop)
results.KS.pop


#########################################################
# Next, we confirm the power-law distributional form for 
# all interstate wars (1816-1997) using the TP-statistic     
#########################################################

x <- sort(na.omit(data2$deaths_isw[data2$subconflict == 0]))

lowerbound <- 3
upperbound <- 7.2
increment <- 0.02
numrows <- floor((upperbound - lowerbound) / increment) + 1

results.TP.isw <- matrix(NA,numrows,6)
colnames(results.TP.isw) <- c("Threshold","Exponent","TP","TPsd","low95","high95")
rowindex <- 1

for (t in seq(lowerbound, upperbound, by = increment)) {
	u <- 10^t
	s <- x[x >= u]
	n <- length(s)
	alpha <- ((sum(log(s/u)))/n)^-1
	TP <- (((1/n)*sum(log(s/u)))^2) - ((0.5/n)*sum((log(s/u))^2))
	TPsd <- (n^(-0.5))*(((1/n)*sum(((2*(1/n)*sum(log(s/u))*log(s/u)) - (0.5*((log(s/u))^2)) - 1/((alpha)^2))^2))^0.5)
	results.TP.isw[rowindex,1] <- u
	results.TP.isw[rowindex,2] <- alpha
	results.TP.isw[rowindex,3] <- TP
	results.TP.isw[rowindex,4] <- TPsd
	results.TP.isw[rowindex,5] <- 0 - (2 * TPsd)
	results.TP.isw[rowindex,6] <- 0 + (2 * TPsd)
	rowindex <- rowindex + 1
}

results.TP.isw <- as.data.frame(results.TP.isw)
results.TP.isw


#######################################################
# Next, we show that the distributions of interstate  
# war sizes are statistically indistiquishable across  
# geographic regions using the Hill estimator and 
# the KS-test   
#######################################################


deaths.eur <- na.omit(data2$deaths_isw[data2$region == "Europe"])
deaths.asia <- na.omit(data2$deaths_isw[data2$region == "Asia"])
deaths.me <- na.omit(data2$deaths_isw[data2$region == "Middle East"])



##################
# Hill estimator #
##################

hill.eur <- ((sum(log(deaths.eur / 1000))) / length(deaths.eur)) ^ -1
hill.asia <- ((sum(log(deaths.asia / 1000))) / length(deaths.asia)) ^ -1
hill.me <- ((sum(log(deaths.me / 1000))) / length(deaths.me)) ^ -1

hill.eur
hill.asia
hill.me

###########
# KS-test #
###########

ks.test(deaths.eur, deaths.asia)
ks.test(deaths.eur, deaths.me)
ks.test(deaths.me, deaths.asia)


#######################################################
# Finally, we show that power-law behavior in per capita 
# rates of military mobilization emerges at the peaks of   
# global mobilization processes, in 1917 and 1945, but is
# largely absent in other years, e.g. 1910 and 1938 
#######################################################


data3 <- read.csv("CWS.milbystate.csv")

lowerbound <- 0.0001
upperbound <- 0.012
increment <- 0.0001
numrows <- floor((upperbound - lowerbound) / increment) + 1

x <- sort(na.omit(data3$mpc_1910))

results.mpc.1910 <- matrix(NA,numrows,6)
colnames(results.mpc.1910) <- c("Threshold","Exponent","TP","TPsd","low95","high95")
rowindex <- 1

for (t in seq(lowerbound, upperbound, by = increment)) {
	u <- t
	s <- x[x >= u]
	n <- length(s)
	alpha <- ((sum(log(s/u)))/n)^-1
	TP <- (((1/n)*sum(log(s/u)))^2) - ((0.5/n)*sum((log(s/u))^2))
	TPsd <- (n^(-0.5))*(((1/n)*sum(((2*(1/n)*sum(log(s/u))*log(s/u)) - (0.5*((log(s/u))^2)) - 1/((alpha)^2))^2))^0.5)
	results.mpc.1910[rowindex,1] <- u
	results.mpc.1910[rowindex,2] <- alpha
	results.mpc.1910[rowindex,3] <- TP
	results.mpc.1910[rowindex,4] <- TPsd
	results.mpc.1910[rowindex,5] <- 0 - (2 * TPsd)
	results.mpc.1910[rowindex,6] <- 0 + (2 * TPsd)
	rowindex <- rowindex + 1
}

results.mpc.1910 <- as.data.frame(results.mpc.1910)



x <- sort(na.omit(data3$mpc_1917))

results.mpc.1917 <- matrix(NA,numrows,6)
colnames(results.mpc.1917) <- c("Threshold","Exponent","TP","TPsd","low95","high95")
rowindex <- 1

for (t in seq(lowerbound, upperbound, by = increment)) {
	u <- t
	s <- x[x >= u]
	n <- length(s)
	alpha <- ((sum(log(s/u)))/n)^-1
	TP <- (((1/n)*sum(log(s/u)))^2) - ((0.5/n)*sum((log(s/u))^2))
	TPsd <- (n^(-0.5))*(((1/n)*sum(((2*(1/n)*sum(log(s/u))*log(s/u)) - (0.5*((log(s/u))^2)) - 1/((alpha)^2))^2))^0.5)
	results.mpc.1917[rowindex,1] <- u
	results.mpc.1917[rowindex,2] <- alpha
	results.mpc.1917[rowindex,3] <- TP
	results.mpc.1917[rowindex,4] <- TPsd
	results.mpc.1917[rowindex,5] <- 0 - (2 * TPsd)
	results.mpc.1917[rowindex,6] <- 0 + (2 * TPsd)
	rowindex <- rowindex + 1
}

results.mpc.1917 <- as.data.frame(results.mpc.1917)


x <- sort(na.omit(data3$mpc_1938))

results.mpc.1938 <- matrix(NA,numrows,6)
colnames(results.mpc.1938) <- c("Threshold","Exponent","TP","TPsd","low95","high95")
rowindex <- 1

for (t in seq(lowerbound, upperbound, by = increment)) {
	u <- t
	s <- x[x >= u]
	n <- length(s)
	alpha <- ((sum(log(s/u)))/n)^-1
	TP <- (((1/n)*sum(log(s/u)))^2) - ((0.5/n)*sum((log(s/u))^2))
	TPsd <- (n^(-0.5))*(((1/n)*sum(((2*(1/n)*sum(log(s/u))*log(s/u)) - (0.5*((log(s/u))^2)) - 1/((alpha)^2))^2))^0.5)
	results.mpc.1938[rowindex,1] <- u
	results.mpc.1938[rowindex,2] <- alpha
	results.mpc.1938[rowindex,3] <- TP
	results.mpc.1938[rowindex,4] <- TPsd
	results.mpc.1938[rowindex,5] <- 0 - (2 * TPsd)
	results.mpc.1938[rowindex,6] <- 0 + (2 * TPsd)
	rowindex <- rowindex + 1
}

results.mpc.1938 <- as.data.frame(results.mpc.1938)


x <- sort(na.omit(data3$mpc_1945))

results.mpc.1945 <- matrix(NA,numrows,6)
colnames(results.mpc.1945) <- c("Threshold","Exponent","TP","TPsd","low95","high95")
rowindex <- 1

for (t in seq(lowerbound, upperbound, by = increment)) {
	u <- t
	s <- x[x >= u]
	n <- length(s)
	alpha <- ((sum(log(s/u)))/n)^-1
	TP <- (((1/n)*sum(log(s/u)))^2) - ((0.5/n)*sum((log(s/u))^2))
	TPsd <- (n^(-0.5))*(((1/n)*sum(((2*(1/n)*sum(log(s/u))*log(s/u)) - (0.5*((log(s/u))^2)) - 1/((alpha)^2))^2))^0.5)
	results.mpc.1945[rowindex,1] <- u
	results.mpc.1945[rowindex,2] <- alpha
	results.mpc.1945[rowindex,3] <- TP
	results.mpc.1945[rowindex,4] <- TPsd
	results.mpc.1945[rowindex,5] <- 0 - (2 * TPsd)
	results.mpc.1945[rowindex,6] <- 0 + (2 * TPsd)
	rowindex <- rowindex + 1
}

results.mpc.1945 <- as.data.frame(results.mpc.1945)


########
# 1910 #
########

results.mpc.1910

########
# 1917 #
########

results.mpc.1917

########
# 1938 #
########

results.mpc.1938

########
# 1945 #
########

results.mpc.1945

#####################################################


